/*download and save "example_chapter7.sas7bdat" in c:\regression*/

libname in 'c:\regression';
run;

/*descriptive statistics*/
proc means data=in.example_chapter7 mean median std var min max var range;
var attempt education;
run;

proc freq data=in.example_chapter7;
table cessation relation;
run;


/*making dummy variables and assigning 0 and 1 to binary Y*/
data analysis1;
set in.example_chapter7;
/*making dummy variables*/
if relation = "Married" then m_dummy = 1;
else m_dummy =0;
if relation = "Unmarried partner" then p_dummy = 1;
else p_dummy = 0;
if relation = "Single" then s_dummy = 1;
else s_dummy =0;

/*assigning 0 and 1 to binary Y*/
if cessation = "Successful" then cessation_binary =1;
else cessation_binary=0;
run;


/*correlation among X's*/

proc corr data=analysis1;
var attempt education M_dummy P_dummy;
run;

/*descriptive statistics*/
proc means data=in.example_chapter7 mean median std var min max var range;
var attempt education;
run;

proc freq data=in.example_chapter7;
table cessation relation;
run;


/*logistic regression model with single as reference category
(Y = cessation_binary, X = attempt, education, M_dummy P_dummy)
and saving the predicted probability in analysis2*/
proc logistic data=analysis1 descending ;
model cessation_binary =  attempt education  M_dummy P_dummy /rsquare;
output out=analysis2 predicted=pred;
run; 


/*classification table*/

data test1;
set analysis2;
if pred>=0.5 then prediction=1;
if pred<=0.5 then prediction=0;
run;

proc freq data=test1;
table cessation_binary * prediction;
run;

/*partial logistic regression model without dummy variables for relation
(Y = cessation_binary, X = attempt, education)*/

proc logistic data=analysis1 descending ;
model cessation_binary =  attempt education/rsquare;
run; 


/*logistic regression model with "Married" as reference category
(Y = cessation_binary, X = attempt, education, p_dummy s_dummy)*/
proc logistic data=analysis1 descending ;
model cessation_binary =  attempt education  P_dummy S_dummy /rsquare;
run; 



/*logistic regression with probability plots*/
proc logistic data=analysis1  descending ;
class relation(ref='Unmarried partner'); /*assign the modal category*/
model cessation_binary =  attempt education relation /rsquare ;
effectplot fit(x=attempt); /*plot of probability for changing values of attempt with education set at its mean and relation set at its modal category*/
effectplot fit(x=education); /*plot of probability of changing values of education with attempt set at its mean and relation set at its modal category*/
run; 















